Plotter API — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# Plotter API

This chapter is intended to describe data types that are used to assist in the plotting of density of states and band stucture.

PyProcar has the following data types:

- `pyprocar.DOSPlot` is used to plot the density of states.

    DOSPlot expects `pyprocar.DensityOfStates` and `pyprocar.Structure`

- `pyprocar.EBSPlot` is used to plot the electronic band structure.

    DOSPlot expects `pyprocar.ElectronicBandStructure`

- EBSPlot
  - pyprocar.plotter.EBSPlot
- DosPlot
  - pyprocar.plotter.DOSPlot
- ProcarPlot
  - pyprocar.plotter.ProcarPlot